[![Publish to PyPI.org](https://github.com/leokster/dingdong_sonos/actions/workflows/publish-pypi.yml/badge.svg?event=release)](https://github.com/leokster/dingdong_sonos/actions/workflows/publish-pypi.yml)

# DinDong

Add some flair to your office routine with the charm of nostalgia. Have you ever yearned for those good old school days when the bell signalled a break? Now, with dingdong-sonos, you can recreate that same anticipation in your office environment. Just one command transforms your Sonos system into a school bell, reminding everyone to take that well-deserved pause. Rediscover the joy of break time with dingdong-sonos 🔔!


# How to use it

```
pip install dingdong-sonos
dingdong
```

You can adjust the volume or set the sonos_ip:
```
dingdong --sonos_ip <ip-of-your-sonos> --volume 80